@@ -263,41 +263,45 @@ func validateLaunchTemplate(launchTemplateData *ec2types.ResponseLaunchTemplateD
 
 func getAMIType(ng *api.ManagedNodeGroup, instanceType string) ekstypes.AMITypes {
 	amiTypeMapping := map[string]struct {
-		X86x64 ekstypes.AMITypes
-		X86GPU ekstypes.AMITypes
-		ARM    ekstypes.AMITypes
-		ARMGPU ekstypes.AMITypes
+		X86x64    ekstypes.AMITypes
+		X86Nvidia ekstypes.AMITypes
+		X86Neuron ekstypes.AMITypes
+		ARM       ekstypes.AMITypes
+		ARMGPU    ekstypes.AMITypes
 	}{
 		api.NodeImageFamilyAmazonLinux2023: {
-			X86x64: ekstypes.AMITypesAl2023X8664Standard,
-			ARM:    ekstypes.AMITypesAl2023Arm64Standard,
+			X86x64:    ekstypes.AMITypesAl2023X8664Standard,
+			X86Nvidia: ekstypes.AMITypesAl2023X8664Nvidia,
+			X86Neuron: ekstypes.AMITypesAl2023X8664Neuron,
+			ARM:       ekstypes.AMITypesAl2023Arm64Standard,
 		},
 		api.NodeImageFamilyAmazonLinux2: {
-			X86x64: ekstypes.AMITypesAl2X8664,
-			X86GPU: ekstypes.AMITypesAl2X8664Gpu,
-			ARM:    ekstypes.AMITypesAl2Arm64,
+			X86x64:    ekstypes.AMITypesAl2X8664,
+			X86Nvidia: ekstypes.AMITypesAl2X8664Gpu,
+			X86Neuron: ekstypes.AMITypesAl2X8664Gpu,
+			ARM:       ekstypes.AMITypesAl2Arm64,
 		},
 		api.NodeImageFamilyBottlerocket: {
-			X86x64: ekstypes.AMITypesBottlerocketX8664,
-			X86GPU: ekstypes.AMITypesBottlerocketX8664Nvidia,
-			ARM:    ekstypes.AMITypesBottlerocketArm64,
-			ARMGPU: ekstypes.AMITypesBottlerocketArm64Nvidia,
+			X86x64:    ekstypes.AMITypesBottlerocketX8664,
+			X86Nvidia: ekstypes.AMITypesBottlerocketX8664Nvidia,
+			ARM:       ekstypes.AMITypesBottlerocketArm64,
+			ARMGPU:    ekstypes.AMITypesBottlerocketArm64Nvidia,
 		},
 		api.NodeImageFamilyWindowsServer2019FullContainer: {
-			X86x64: ekstypes.AMITypesWindowsFull2019X8664,
-			X86GPU: ekstypes.AMITypesWindowsFull2019X8664,
+			X86x64:    ekstypes.AMITypesWindowsFull2019X8664,
+			X86Nvidia: ekstypes.AMITypesWindowsFull2019X8664,
 		},
 		api.NodeImageFamilyWindowsServer2019CoreContainer: {
-			X86x64: ekstypes.AMITypesWindowsCore2019X8664,
-			X86GPU: ekstypes.AMITypesWindowsCore2019X8664,
+			X86x64:    ekstypes.AMITypesWindowsCore2019X8664,
+			X86Nvidia: ekstypes.AMITypesWindowsCore2019X8664,
 		},
 		api.NodeImageFamilyWindowsServer2022FullContainer: {
-			X86x64: ekstypes.AMITypesWindowsFull2022X8664,
-			X86GPU: ekstypes.AMITypesWindowsFull2022X8664,
+			X86x64:    ekstypes.AMITypesWindowsFull2022X8664,
+			X86Nvidia: ekstypes.AMITypesWindowsFull2022X8664,
 		},
 		api.NodeImageFamilyWindowsServer2022CoreContainer: {
-			X86x64: ekstypes.AMITypesWindowsCore2022X8664,
-			X86GPU: ekstypes.AMITypesWindowsCore2022X8664,
+			X86x64:    ekstypes.AMITypesWindowsCore2022X8664,
+			X86Nvidia: ekstypes.AMITypesWindowsCore2022X8664,
 		},
 	}
 
@@ -307,13 +311,14 @@ func getAMIType(ng *api.ManagedNodeGroup, instanceType string) ekstypes.AMITypes
 	}
 
 	switch {
-	case instanceutils.IsGPUInstanceType(instanceType):
-		if instanceutils.IsARMInstanceType(instanceType) {
-			return amiType.ARMGPU
-		}
-		return amiType.X86GPU
+	case instanceutils.IsARMGPUInstanceType(instanceType):
+		return amiType.ARMGPU
 	case instanceutils.IsARMInstanceType(instanceType):
 		return amiType.ARM
+	case instanceutils.IsNvidiaInstanceType(instanceType):
+		return amiType.X86Nvidia
+	case instanceutils.IsNeuronInstanceType(instanceType):
+		return amiType.X86Neuron
 	default:
 		return amiType.X86x64
 	}
